@@ -1,6 +1,6 @@
 package Grimlock::Web::View::JSON;
 {
-  $Grimlock::Web::View::JSON::VERSION = '0.10';
+  $Grimlock::Web::View::JSON::VERSION = '0.11';
 }
 
 use strict;
@@ -10,7 +10,8 @@ use Try::Tiny;
 
 sub encode_json {
     my($self, $c, $data) = @_;
-    my $encoder = JSON::XS->new->ascii->pretty->allow_nonref->convert_blessed->allow_blessed;
+    my $encoder = JSON::XS->new->ascii->allow_nonref->convert_blessed->allow_blessed;
+    $encoder->pretty if $c->debug;
     my $d = $encoder->encode($data);
     return $d;
 }
